<template>
    <!-- 设备绑定队员 -->
    <el-dialog title="绑定队员" width="75%" :visible.sync="showFormDia" :before-close="handleClose" top="9vh">
        <div class="tree-table-container">
            <el-row class="fullheight">
                <el-col :span="4" class="fullheight" style="height: 65vh;">
                    <div class="common-tree-container">
                        <div class="common-tree-title">
                            <i class="el-icon-menu" /> 组织目录
                        </div>
                        <div class="common-tree-content">
                            <el-tree highlight-current :data="depts" :props="defaultProps" @node-click="handleNodeClick"
                                default-expand-all />
                        </div>
                    </div>
                </el-col>
                <el-col :span="20" class="fullheight">
                    <div class="common-table-container">
                        <div class="bbsl-common-page">
                            <div class="bbsl-table-search">
                                <el-form v-model="queryParam" :inline="true">
                                    <el-form-item label="姓名">
                                        <el-input v-model="querys[0].value" clearable placeholder="请输入姓名" />
                                    </el-form-item>
                                    <el-form-item>
                                        <el-button type="primary" icon="el-icon-search"
                                            @click="handleSearch">搜索</el-button>
                                        <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
                                    </el-form-item>
                                </el-form>
                            </div>
                            <div ref="contentPanel" class="bbsl-table-content">
                                <el-table ref="multipleSelection" v-loading="loading" border size="mini"
                                    :data="tableData" :style="{ width: '100%' }" :height="400"
                                    :cell-style="{ 'text-align': 'center' }" highlight-current-row
                                    :header-cell-style="{ 'text-align': 'center' }"
                                    @current-change="handleTableCurrentChange">
                                    <el-table-column fixed type="index" width="55" label="序号" />
                                    <el-table-column fixed prop="code" label="编号" show-overflow-tooltip />
                                    <el-table-column prop="name" label="姓名" show-overflow-tooltip />
                                    <el-table-column prop="orgName" label="所属部门" show-overflow-tooltip />
                                    <el-table-column prop="post" label="职位" show-overflow-tooltip />
                                    <el-table-column prop="cmgtDutyJob.name" label="岗位" show-overflow-tooltip />
                                    <el-table-column prop="phone" label="联系电话" show-overflow-tooltip />
                                    <el-table-column prop="phone" label="是否绑定设备" show-overflow-tooltip>
                                        <template v-slot="{ row }">
                                            <el-tag v-if="row.deviceCode" type="success">已绑定</el-tag>
                                            <el-tag v-else type="info">未绑定</el-tag>
                                        </template>
                                    </el-table-column>
                                </el-table>
                                <el-pagination ref="paginationPanel" align="right" background
                                    :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                                    :page-size="queryParam.pageBean.pageSize"
                                    layout="total, sizes, prev, pager, next, jumper" :total="total"
                                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
                            </div>
                        </div>
                    </div>
                </el-col>
            </el-row>
        </div>
        <span slot="footer" class="dialog-footer">
            <el-button :loading="bindLoading" type="primary" @click="confirmBinding">绑 定</el-button>
            <el-button @click="handleClose">取 消</el-button>
        </span>
    </el-dialog>
</template>
<script>
import TeamMemberManage from '@/api/manager/duty/teamMemberManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import CmgtDutyJobApi from '@/views/Manage/duty/api/CmgtDutyJobApi'
import CommonApi from '@/views/Manage/CommonApi.js'
export default {
    name: 'CmgtDutyWorkarrangeFormDialog',
    components: {},
    data() {
        return {
            tableMaxHeight: 300,
            loading: false,
            showFormDia: false,
            defaultProps: {
                value: 'id',
                label: 'name',
                parentId: 'parentId',
                code: 'code',
                children: 'children'
            },
            total: 0,
            queryParam: {
                pageBean: {
                    pageSize: 20,
                    page: 1
                },
                params: {},
                querys: []
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'm.name_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'IN',
                    parentGroup: '',
                    property: 'team_id_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'm.org_id_',
                    relation: 'AND',
                    value: ''
                }
            ],
            StshowFormDias: false,
            posts: [],
            teams: [],
            depts: [],
            currentTreeNode: '',
            deviceList: [], // 执法仪列表
            memberInfo: null,
            equipmentInfo: null,
            tableData: [],
            bindLoading: false
        }
    },
    created() {
        this.loadOrg()
        this.actionUrl = window.context.portal
        this.getDeviceCode()
    },
    mounted() {
    },
    methods: {
        loadOrg() {
            CommonApi.getAllOrgTree(res => {
                this.depts = res.data
            })
        },
        // 表格选中
        handleTableCurrentChange(val) {
            console.log(val);

            this.memberInfo = val
        },
        confirmBinding() {
            if (this.memberInfo) {
                const { name, code: deviceCode } = this.equipmentInfo
                const { name: memberName, id: memberId, deviceCode: code } = this.memberInfo
                let msg = code ? `${memberName}已绑定设备，确认将设备${name}与${memberName}重新进行绑定吗？` : `确定将设备${name}与${memberName}进行绑定吗？`
                this.$confirm(msg, '提示', {
                    confirmButtonText: '确认',
                    cancelButtonText: '取消',
                    type: 'warning'
                }).then(() => {
                    this.bindLoading = true
                    CmgtDutyJobApi.deviceBindingUnbinding({ memberId, deviceCode }, res => {
                        if (res.state) {
                            this.$message.success('绑定成功。')
                            this.handleClose()
                            this.$emit('refreshData')
                        }
                        this.bindLoading = false
                    })
                })
            } else {
                this.$message.error('请选择队员进行设备绑定！')
            }
        },
        open(item) {
            this.equipmentInfo = item
            this.loadData(1)
            this.showFormDia = true
        },
        // 获取执法记录仪信息
        getDeviceCode() {
            let obj = {
                groupRelation: 'AND',
                groupTree: {},
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    showTotal: true
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'p.code_',
                        relation: 'AND',
                        value: 'ydzfjly'
                    }
                ]
            }
            TeamMemberManage.getDeviceInfo(obj, res => {
                console.log(res)
                this.deviceList = res.rows
            })
        },
        renderTreeNode(data) {
            if (data != null && data.length > 0) {
                var orgNames = new Set()
                data.forEach(item => {
                    orgNames.add(item.orgName)
                })
                var treeNodes = []
                orgNames.forEach(item => {
                    var pid = []
                    var child = data.filter(c => {
                        if (c.orgName === item) {
                            pid.push(c.id)
                            return c
                        }
                    })
                    var node = {
                        id: pid.join(','),
                        name: item,
                        children: child
                    }
                    treeNodes.push(node)
                })
                this.depts = treeNodes
            } else {
                this.depts = []
            }
        },
        handleNodeClick(data) {
            // 点击分类树节点
            this.currentTreeNode = data
            this.loadData(1)
        },
        // 重置
        clearQuerys() {
            this.querys[0].value = ''
            this.querys[1].value = null
            this.querys[2].value = null
            this.currentTreeNode = ''
        },
        // 获取list
        loadData(page) {
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.loading = true
            this.tableData = []
            this.queryParam.querys = []
            if (this.querys[0].value) {
                this.queryParam.querys.push(this.querys[0])
            }
            if (this.currentTreeNode) {
                // if (this.currentTreeNode.dataType === 'ORG') {
                //     this.querys[2].value = this.currentTreeNode.id
                //     this.queryParam.querys.push(this.querys[2])
                // } else {
                //     this.querys[1].value = this.currentTreeNode.id
                //     this.queryParam.querys.push(this.querys[1])
                // }
                this.querys[2].value = this.currentTreeNode.id
                this.queryParam.querys.push(this.querys[2])
            }
            TeamMemberManage.pageQuery(this.queryParam).then(res => {
                const {
                    data: { total, rows }
                } = res
                this.total = total
                this.tableData = rows
                this.tableData.forEach(item => {
                    this.deviceList.forEach(it => {
                        if (item.deviceCode === it.code) {
                            item.deviceCodeName = it.name
                        }
                    })
                })
                this.$set(this.tableData)
                this.loading = false
            })
        },
        handleReset() {
            this.queryParam.params = {}
            this.queryParam.querys = []
            this.clearQuerys && this.clearQuerys()
            this.handleSearch()
        },
        handleSearch() {
            this.queryParam.pageBean.page = 1
            this.loadData()
        },
        handleSizeChange(val) {
            this.queryParam.pageBean.pageSize = val
            this.loadData(1)
        },
        handleCurrentChange(val) {
            this.queryParam.pageBean.page = val
            this.loadData()
        },
        closeStshowForm() {
            this.StshowFormDias = false
        },
        teamFormat(row, column, cellValue, index) {
            for (var i = 0; i < this.teams.length; i++) {
                if (cellValue === this.teams[i].id) {
                    return this.teams[i].name
                }
            }
        },
        orgFormat(row, column, cellValue, index) {
            for (var i = 0; i < this.teams.length; i++) {
                if (cellValue === this.teams[i].id) {
                    return this.teams[i].orgName
                }
            }
        },
        handleClose() {
            this.memberInfo = null
            this.equipmentInfo = null
            this.tableData = []
            this.showFormDia = false
        }
    }
}
</script>
<style lang="scss" scoped>
.common-tree-container {
    box-shadow: none !important;
}

::v-deep.el-dialog__body {
    height: 65vh;
}

::v-deep.bbsl-table-search,
::v-deep.bbsl-table-content {
    box-shadow: none;
}

::v-deep.bbsl-table-content {
    margin-top: 0;
    padding: 0 20px;
    // height: 55vh;
}

.step-container {
    width: 80%;
    margin: 0 auto 20px;
}

.dialog-footer {
    text-align: center;
}
</style>